summaryrefslogtreecommitdiffstats
path: root/sys/pci/aic7870.c
diff options
context:
space:
mode:
Diffstat (limited to 'sys/pci/aic7870.c')
-rw-r--r--sys/pci/aic7870.c11
1 files changed, 9 insertions, 2 deletions
diff --git a/sys/pci/aic7870.c b/sys/pci/aic7870.c
index 6028455..e0e4733 100644
--- a/sys/pci/aic7870.c
+++ b/sys/pci/aic7870.c
@@ -1,6 +1,6 @@
/*
* Product specific probe and attach routines for:
* 294X and aic7870 motherboard SCSI controllers
*
* Copyright (c) 1995 Justin T. Gibbs
* All rights reserved.
@@ -19,7 +19,7 @@
* 4. Modifications may be freely made to this file if the above conditions
* are met.
*
- * $Id: aic7870.c,v 1.9 1995/04/15 21:38:34 gibbs Exp $
+ * $Id: aic7870.c,v 1.10.2.2 1995/06/09 18:06:53 davidg Exp $
*/
#include <pci.h>
@@ -37,6 +37,7 @@
#define PCI_BASEADR0 PCI_MAP_REG_START
#define PCI_DEVICE_ID_ADAPTEC_2940 0x71789004ul
#define PCI_DEVICE_ID_ADAPTEC_AIC7870 0x70789004ul
+#define PCI_DEVICE_ID_ADAPTEC_AIC7850 0x70759004ul
static char* aic7870_probe __P((pcici_t tag, pcidi_t type));
void aic7870_attach __P((pcici_t config_id, int unit));
@@ -63,6 +64,9 @@ aic7870_probe (pcici_t tag, pcidi_t type)
case PCI_DEVICE_ID_ADAPTEC_AIC7870:
return ("Adaptec aic7870 SCSI host adapter");
break;
+ case PCI_DEVICE_ID_ADAPTEC_AIC7850:
+ return ("Adaptec aic7850 SCSI host adapter");
+ break;
default:
break;
}
@@ -95,6 +99,9 @@ aic7870_attach(config_id, unit)
case PCI_DEVICE_ID_ADAPTEC_AIC7870:
ahc_t = AHC_AIC7870;
break;
+ case PCI_DEVICE_ID_ADAPTEC_AIC7850:
+ ahc_t = AHC_AIC7850;
+ break;
default:
break;
}
@@ -1,6 +1,6 @@
/*
* Product specific probe and attach routines for:
- * 294X and aic7870 motherboard SCSI controllers
+ * 2940, aic7870, and aic7850 motherboard SCSI controllers
*
* Copyright (c) 1995 Justin T. Gibbs
OpenPOWER on IntegriCloud